@@ -66,6 +66,10 @@ separator <-
 #' to the current working directory.  If the \code{file_name} does 
 #' not have a '.log' extension, the \code{log_open} function will add it.
 #' 
+#' As of v1.2.7, if the \code{file_name} parameter is not supplied,
+#' the function will use the program/script name as the default
+#' log file name, and the program/script path as the default path.
+#' 
 #' If requested in the \code{logdir} parameter, the \code{log_open}
 #' function will write to a 'log' subdirectory of the path specified in the 
 #' \code{file_name}.  If the 'log' subdirectory does not exist, 
@@ -116,7 +120,9 @@ separator <-
 #' \code{logr.autolog} to TRUE.  To maintain backward compatibility with 
 #' prior versions, autolog is disabled by default. 
 #' @param file_name The name of the log file.  If no path is specified, the 
-#' working directory will be used.
+#' working directory will be used.  As of v1.2.7, the name and path of the 
+#' program or script will be used as a default if the \code{file_name} parameter
+#' is not supplied.
 #' @param logdir Send the log to a log directory named "log".  If the log 
 #' directory does not exist, the function will create it.  Valid values are 
 #' TRUE and FALSE. The default is TRUE.
@@ -210,8 +216,19 @@ log_open <- function(file_name = "", logdir = TRUE, show_notes = TRUE,
   # If no filename is specified, make up something.
   # If R had a good way of getting the name of the currently
   # executing script, I would do that instead.  But it doesn't.
-  if (file_name == "")
-    file_name = "script.log"
+  if (file_name == "") {
+    
+    ppth <- NULL
+    tryCatch({
+      ppth <- this.path::this.path()
+    }, error = function(e) { ppth <- NULL})
+    
+    if (is.null(ppth))
+      file_name <-  "script.log"
+    else 
+      file_name <- sub(pattern = "(.*)\\..*$", replacement = "\\1", ppth)
+    
+  }
   
   if (file_name != "") {
     
@@ -619,257 +636,3 @@ error_handler <- function() {
 #   log_quiet(warnings(), msg = TRUE)
 #   
 # }
-
-
-# Utilities ---------------------------------------------------------------
-
-#' @noRd
-update_status <- function() {
-  
-  if (!is.null(options("logr.on")[[1]])) {
-    
-    if(options("logr.on")[[1]] == FALSE)
-      e$log_status <- "off"
-    else if (options("logr.on")[[1]] == TRUE & e$log_status == "off")
-      e$log_status <- "on"
-    
-  }
-  
-  if (!is.null(options("logr.autolog")[[1]])) {
-    
-    if(options("logr.autolog")[[1]] == FALSE)
-      e$autolog <- FALSE
-    else if (options("logr.autolog")[[1]] == TRUE)
-      e$autolog <- TRUE
-  }
-  
-  if (!is.null(options("logr.notes")[[1]])) {
-    
-    if(options("logr.notes")[[1]] == FALSE)
-      e$log_show_notes <- FALSE
-    else if (options("logr.notes")[[1]] == TRUE)
-      e$log_show_notes <- TRUE
-  }
-
-}
-
-
-#' Function to print the log header
-#' @import this.path
-#' @noRd
-print_log_header <- function(log_path) {
-  
-  log_quiet(paste(separator), blank_after = FALSE)
-  log_quiet(paste("Log Path:", log_path), blank_after = FALSE)
-  
-  ppth <- NULL
-  tryCatch({
-    ppth <- this.path::this.path()
-  }, error = function(e) { ppth <- NULL})
-  
-  if (!is.null(ppth)) {
-    if (file.exists(ppth))
-      log_quiet(paste("Program Path:", ppth), blank_after = FALSE)
-  }
-  
-  
-  log_quiet(paste("Working Directory:", getwd()), blank_after = FALSE)
-  
-  inf <- Sys.info()
-  log_quiet(paste("User Name:", inf["user"]), blank_after = FALSE)
-  
-  vr <- sub("R version ", "", R.Version()["version.string"])
-  log_quiet(paste("R Version:", vr), blank_after = FALSE)
-  log_quiet(paste("Machine:", inf["nodename"], inf["machine"]), 
-            blank_after = FALSE)
-
-  log_quiet(paste("Operating System:", inf["sysname"], inf["release"], 
-                  inf["version"]), 
-            blank_after = FALSE)
-  
-  log_quiet(paste("Log Start Time:", Sys.time()), blank_after = FALSE)
-  log_quiet(paste(separator))
-}
-
-#' Function to print the log footer
-#' @noRd
-print_log_footer <- function(has_warnings = FALSE) {
-  
-  tc <- Sys.time()
-  
-  if (e$log_show_notes == "TRUE" & has_warnings) {
-    
-    # Force notes after warning print, before the footer
-    log_quiet(paste("NOTE: Log Print Time:", Sys.time()), blank_after = FALSE)
-    log_quiet(paste("NOTE: Log Elapsed Time:", get_time_diff(tc)), 
-              blank_after = TRUE)
-  }
-  
-  # Calculate total elapsed execution time
-  ts <- e$log_start_time
-  #tn <- as.POSIXct(as.double(ts), origin = "1970-01-01")
-  lt <-  tc - ts
-
-  # Print the log footer
-  log_quiet(paste(separator), blank_after = FALSE)
-  log_quiet(paste("Log End Time:", tc),  blank_after = FALSE)
-  log_quiet(paste("Log Elapsed Time:", dhms(as.numeric(lt))), blank_after = FALSE)
-  log_quiet(paste(separator), blank_after = FALSE)
-}
-
-#' Get time difference between last log_print call and current call
-#' @noRd
-get_time_diff <- function(x) {
-  
-  # Pull timestamp out of environment variable
-  ts <- e$log_time
-  
-  # Convert string to time
-  #tn <- as.POSIXct(as.double(ts), origin = "1970-01-01")
-  
-  # Get difference
-  ret <- x - ts
-  
-  # Set new timestamp
-  e$log_time = x
-  
-  return(ret)
-}
-
-#' Little function to format time in seconds into 
-#' days, hours, minutes, and seconds.  Stolen from StackOverflow.
-#' Did not want to create a dependency on external package to do it.
-#' @noRd
-dhms <- function(t){
-  paste(t %/% (60*60*24) 
-        ,paste(formatC(t %/% (60*60) %% 24, width = 2, format = "d", flag = "0")
-               ,formatC(t %/% 60 %% 60, width = 2, format = "d", flag = "0")
-               ,formatC(t %% 60, width = 2, format = "d", flag = "0")
-               ,sep = ":"
-        )
-  )
-}
-
-#' @description Should not be this complicated.  Unfortunately, tidylog
-#' decided to use a Unicode ellipsis character in their log entries. 
-#' This character causes gsub to crash. grep just gives a warning.
-#' So we suppressWarnings, find the lines with strings to replace, 
-#' then loop through each and tryCatch to suppress the error.  Horrible pain.
-#' 
-#' This whole thing is necessary because crayon codes are still being printed
-#' to the log.  So the purpose of the function is to remove the crayon
-#' color codes.  Generally, should not have to do this.
-#' @noRd
-clear_codes <- function(path = NULL) {
-  
-  if (is.null(path))
-    pth <- e$log_path
-  else 
-    pth <- path
-  
-  
-  if (file.exists(pth)) {
-  
-    lns <- readLines(pth, encoding = "UTF-8")
-    
-    f <- file(pth, open = "w", encoding = "native.enc")
-    #f <- file(pth, open = "w", encoding = "UTF-8")
-    
-    # lns <- gsub("[90m", "", lns, fixed = TRUE)
-    res90 <- suppressWarnings(grep("\033[90m", lns, fixed = TRUE))
-    res39 <- suppressWarnings(grep("\033[39m", lns, fixed = TRUE))
-    #lns <- gsub("\033[39m", "", lns, fixed = TRUE, useBytes = TRUE)
-    
-    if (length(res90) > 0 | length(res39) > 0) {
-     # print(res90)
-    #  print(res39)
-      
-      if (length(res90) > 0) {
-        for (ln in res90) {
-          tryCatch({ 
-            lns[ln] <- gsub("\033[90m", "", lns[ln], fixed = TRUE)
-          })
-        }
-      }
-      
-      if (length(res39) > 0) {
-        for (ln in res39) {
-          tryCatch({ 
-            lns[ln] <- gsub("\033[39m", "", lns[ln], fixed = TRUE)
-          })
-        }
-      }
-    }
-    
-    
-    # Print the string
-    writeLines(lns, con = f, useBytes = TRUE)
-    
-    # Close file
-    close(f) 
-    
-    
-  }
-  
-}
-
-# Test Case ---------------------------------------------------------------
-# 
-# library(logr)
-# 
-# 
-# options("logr.on" = TRUE)
-# options("logr.notes" = FALSE)
-# 
-# e$log_status
-# 
-# library(tibble)
-# 
-# file.remove(lf)
-# tmp <- file.path(tempdir(), "test.log")
-# 
-# lf <- log_open(tmp)
-# 
-# str <- "High Mileage Cars Subset and some more stuff and more and more and let's see how far we can go."
-# 
-# v2 <- strwrap(str, 76)
-# 
-# paste(v2, sep = "|", collapse = "+")
-# 
-# sep(str)
-# 
-# hmc <- tibble(subset(mtcars, mtcars$mpg > 20))
-# log_print(hmc)
-# 
-# log_print("Here is a character vector")
-# v1 <- c("1", "2", "3")
-# log_print(v1)
-# 
-# 
-# sep("Here is a numeric \nvector")
-# v2 <- c(1, 2, 3)
-# log_print(v2)
-# 
-# log_print("Here is a factor")
-# f1 <- factor(c("A", "B", "B", "A"), levels = c("A", "B"))
-# log_print(f1)
-# 
-# log_print("Here is a list")
-# l1 <- list("A", 1, Sys.Date())
-# log_print(l1)
-# 
-# # generror
-# # warning("Test warning")
-# 
-# 
-# log_close()
-# 
-# writeLines(readLines(lf))
-
-
-
-
-
-
-
-
